#####
tight
#####

.. image:: https://readthedocs.org/projects/tight-cli/badge/?version=latest
    :target: http://tight-cli.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://travis-ci.org/Lululemon/tight.svg?branch=master
    :target: https://travis-ci.org/Lululemon/tight

.. image:: https://codecov.io/gh/Lululemon/tight/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/Lululemon/tight

.. image:: https://codeclimate.com/github/Lululemon/tight/badges/gpa.svg
   :target: https://codeclimate.com/github/Lululemon/tight
   :alt: Code Climate


----

Tight is a microframework created and optimized for serverless runtimes. With ``tight-cli`` and ``tight`` you can quickly scaffold serverless applications that are conventional, testable-by-default and free of boilerplate.

**Tight currently supports AWS Lambda and the Python3.6 runtime.**

The best way to get started with Tight is to follow the `tutorial <http://tight-cli.readthedocs.io/en/latest/topics/tutorial.html>`_, which will guide you through the process of building and deploying an app. There are also references for both `tight <http://tight-cli.readthedocs.io/en/latest/topics/tight_reference.html>`_ and `tight-cli <http://tight-cli.readthedocs.io/en/latest/topics/reference.html>`_.

###########
Development
###########

* `pip install -e .`
* `pip install -r requirements.txt`
